Module: Google::Apis::BigqueryreservationV1

Defined in:
lib/google/apis/bigqueryreservation_v1.rb,
lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/service.rb,
lib/google/apis/bigqueryreservation_v1/gem_version.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb

Overview

BigQuery Reservation API

A service to modify your BigQuery reservations.

Defined Under Namespace

Classes: Assignment, AuditConfig, AuditLogConfig, Autoscale, BiReservation, BigQueryReservationService, Binding, CapacityCommitment, Empty, Expr, FailoverReservationRequest, ListAssignmentsResponse, ListCapacityCommitmentsResponse, ListReservationGroupsResponse, ListReservationsResponse, MergeCapacityCommitmentsRequest, MoveAssignmentRequest, Policy, ReplicationStatus, Reservation, ReservationGroup, SchedulingPolicy, SearchAllAssignmentsResponse, SearchAssignmentsResponse, SetIamPolicyRequest, SplitCapacityCommitmentRequest, SplitCapacityCommitmentResponse, Status, TableReference, TestIamPermissionsRequest, TestIamPermissionsResponse

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-bigqueryreservation_v1 gem

"0.52.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260410"
VERSION =

Version of the BigQuery Reservation API this client connects to. This is NOT the gem version.

'V1'
AUTH_BIGQUERY =

View and manage your data in Google BigQuery and see the email address for your Google Account

'https://www.googleapis.com/auth/bigquery'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'