Class: Google::Apis::BigqueryreservationV1::Autoscale

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb

Overview

Auto scaling settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Autoscale

Returns a new instance of Autoscale.



189
190
191
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_slotsFixnum

Output only. The slot capacity added to this reservation when autoscale happens. Will be between [0, max_slots]. Note: after users reduce max_slots, it may take a while before it can be propagated, so current_slots may stay in the original value and could be larger than max_slots for that brief period ( less than one minute) Corresponds to the JSON property currentSlots

Returns:

  • (Fixnum)


182
183
184
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 182

def current_slots
  @current_slots
end

#max_slotsFixnum

Optional. Number of slots to be scaled when needed. Corresponds to the JSON property maxSlots

Returns:

  • (Fixnum)


187
188
189
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 187

def max_slots
  @max_slots
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



194
195
196
197
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 194

def update!(**args)
  @current_slots = args[:current_slots] if args.key?(:current_slots)
  @max_slots = args[:max_slots] if args.key?(:max_slots)
end