Class: Google::Apis::BigqueryreservationV1::BigQueryReservationService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BigqueryreservationV1::BigQueryReservationService
- Defined in:
- lib/google/apis/bigqueryreservation_v1/service.rb
Overview
BigQuery Reservation API
A service to modify your BigQuery reservations.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://bigqueryreservation.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_capacity_commitment(parent, capacity_commitment_object = nil, capacity_commitment_id: nil, enforce_single_admin_project_per_org: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Creates a new capacity commitment resource.
-
#create_project_location_reservation(parent, reservation_object = nil, reservation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Creates a new reservation resource.
-
#create_project_location_reservation_assignment(parent, assignment_object = nil, assignment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Assignment
Creates an assignment object which allows the given project to submit jobs of a certain type using slots from the specified reservation.
-
#create_project_location_reservation_group(parent, reservation_group_object = nil, reservation_group_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ReservationGroup
Creates a new reservation group.
-
#delete_project_location_capacity_commitment(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a capacity commitment.
-
#delete_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a reservation.
-
#delete_project_location_reservation_assignment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a assignment.
-
#delete_project_location_reservation_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a reservation.
-
#failover_reservation(name, failover_reservation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Fail over a reservation to the secondary location.
-
#get_project_location_bi_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::BiReservation
Retrieves a BI reservation.
-
#get_project_location_capacity_commitment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Returns information about the capacity commitment.
-
#get_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Returns information about the reservation.
-
#get_project_location_reservation_assignment_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Gets the access control policy for a resource.
-
#get_project_location_reservation_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ReservationGroup
Returns information about the reservation group.
-
#get_project_location_reservation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Gets the access control policy for a resource.
-
#initialize ⇒ BigQueryReservationService
constructor
A new instance of BigQueryReservationService.
-
#list_project_location_capacity_commitments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListCapacityCommitmentsResponse
Lists all the capacity commitments for the admin project.
-
#list_project_location_reservation_assignments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListAssignmentsResponse
Lists assignments.
-
#list_project_location_reservation_groups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListReservationGroupsResponse
Lists all the reservation groups for the project in the specified location.
-
#list_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListReservationsResponse
Lists all the reservations for the project in the specified location.
-
#merge_capacity_commitments(parent, merge_capacity_commitments_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Merges capacity commitments of the same plan into a single commitment.
-
#move_assignment(name, move_assignment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Assignment
Moves an assignment under a new reservation.
-
#patch_project_location_capacity_commitment(name, capacity_commitment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Updates an existing capacity commitment.
-
#patch_project_location_reservation(name, reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Updates an existing reservation resource.
-
#patch_project_location_reservation_assignment(name, assignment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Assignment
Updates an existing assignment.
-
#patch_project_location_reservation_group(name, reservation_group_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ReservationGroup
Updates an existing reservation group resource.
-
#search_project_location_all_assignments(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::SearchAllAssignmentsResponse
Looks up assignments for a specified resource for a particular region.
-
#search_project_location_assignments(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::SearchAssignmentsResponse
Deprecated: Looks up assignments for a specified resource for a particular region.
-
#set_assignment_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Sets an access control policy for a resource.
-
#set_reservation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Sets an access control policy for a resource.
-
#split_capacity_commitment(name, split_capacity_commitment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentResponse
Splits capacity commitment to two commitments of the same plan and
commitment_end_time. -
#test_assignment_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse
Gets your permissions on a resource.
-
#test_reservation_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse
Gets your permissions on a resource.
-
#update_project_location_bi_reservation(name, bi_reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::BiReservation
Updates a BI reservation.
Constructor Details
#initialize ⇒ BigQueryReservationService
Returns a new instance of BigQueryReservationService.
47 48 49 50 51 52 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-bigqueryreservation_v1', client_version: Google::Apis::BigqueryreservationV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_project_location_capacity_commitment(parent, capacity_commitment_object = nil, capacity_commitment_id: nil, enforce_single_admin_project_per_org: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Creates a new capacity commitment resource.
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 260 def create_project_location_capacity_commitment(parent, capacity_commitment_object = nil, capacity_commitment_id: nil, enforce_single_admin_project_per_org: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/capacityCommitments', ) command.request_representation = Google::Apis::BigqueryreservationV1::CapacityCommitment::Representation command.request_object = capacity_commitment_object command.response_representation = Google::Apis::BigqueryreservationV1::CapacityCommitment::Representation command.response_class = Google::Apis::BigqueryreservationV1::CapacityCommitment command.params['parent'] = parent unless parent.nil? command.query['capacityCommitmentId'] = capacity_commitment_id unless capacity_commitment_id.nil? command.query['enforceSingleAdminProjectPerOrg'] = enforce_single_admin_project_per_org unless enforce_single_admin_project_per_org.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_reservation(parent, reservation_object = nil, reservation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Creates a new reservation resource.
700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 700 def create_project_location_reservation(parent, reservation_object = nil, reservation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/reservations', ) command.request_representation = Google::Apis::BigqueryreservationV1::Reservation::Representation command.request_object = reservation_object command.response_representation = Google::Apis::BigqueryreservationV1::Reservation::Representation command.response_class = Google::Apis::BigqueryreservationV1::Reservation command.params['parent'] = parent unless parent.nil? command.query['reservationId'] = reservation_id unless reservation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_reservation_assignment(parent, assignment_object = nil, assignment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Assignment
Creates an assignment object which allows the given project to submit jobs of
a certain type using slots from the specified reservation. Currently a
resource (project, folder, organization) can only have one assignment per each
(job_type, location) combination, and that reservation will be used for all
jobs of the matching type. Different assignments can be created on different
levels of the projects, folders or organization hierarchy. During query
execution, the assignment is looked up at the project, folder and organization
levels in that order. The first assignment found is applied to the query. When
creating assignments, it does not matter if other assignments exist at higher
levels. Example: * The organization organizationA contains two projects,
project1 and project2. * Assignments for all three entities (organizationA
, project1, and project2) could all be created and mapped to the same or
different reservations. "None" assignments represent an absence of the
assignment. Projects assigned to None use on-demand pricing. To create a "None"
assignment, use "none" as a reservation_id in the parent. Example parent:
projects/myproject/locations/US/reservations/none. Returns google.rpc.Code.
PERMISSION_DENIED if user does not have 'bigquery.admin' permissions on the
project using the reservation and the project that owns this reservation.
Returns google.rpc.Code.INVALID_ARGUMENT when location of the assignment
does not match location of the reservation.
1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1059 def create_project_location_reservation_assignment(parent, assignment_object = nil, assignment_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/assignments', ) command.request_representation = Google::Apis::BigqueryreservationV1::Assignment::Representation command.request_object = assignment_object command.response_representation = Google::Apis::BigqueryreservationV1::Assignment::Representation command.response_class = Google::Apis::BigqueryreservationV1::Assignment command.params['parent'] = parent unless parent.nil? command.query['assignmentId'] = assignment_id unless assignment_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_reservation_group(parent, reservation_group_object = nil, reservation_group_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ReservationGroup
Creates a new reservation group.
523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 523 def create_project_location_reservation_group(parent, reservation_group_object = nil, reservation_group_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/reservationGroups', ) command.request_representation = Google::Apis::BigqueryreservationV1::ReservationGroup::Representation command.request_object = reservation_group_object command.response_representation = Google::Apis::BigqueryreservationV1::ReservationGroup::Representation command.response_class = Google::Apis::BigqueryreservationV1::ReservationGroup command.params['parent'] = parent unless parent.nil? command.query['reservationGroupId'] = reservation_group_id unless reservation_group_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_capacity_commitment(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a capacity commitment. Attempting to delete capacity commitment before
its commitment_end_time will fail with the error code google.rpc.Code.
FAILED_PRECONDITION.
301 302 303 304 305 306 307 308 309 310 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 301 def delete_project_location_capacity_commitment(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::Empty::Representation command.response_class = Google::Apis::BigqueryreservationV1::Empty command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a reservation. Returns google.rpc.Code.FAILED_PRECONDITION when
reservation has assignments.
735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 735 def delete_project_location_reservation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::Empty::Representation command.response_class = Google::Apis::BigqueryreservationV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_reservation_assignment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a assignment. No expansion will happen. Example: * Organization
organizationA contains two projects, project1 and project2. * Reservation
res1 exists and was created previously. * CreateAssignment was used
previously to define the following associations between entities and
reservations: and In this example, deletion of the assignment won't
affect the other assignment. After said deletion, queries from project1
will still use res1 while queries from project2 will switch to use on-
demand mode.
1100 1101 1102 1103 1104 1105 1106 1107 1108 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1100 def delete_project_location_reservation_assignment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::Empty::Representation command.response_class = Google::Apis::BigqueryreservationV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_reservation_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Empty
Deletes a reservation. Returns google.rpc.Code.FAILED_PRECONDITION when
reservation has assignments.
558 559 560 561 562 563 564 565 566 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 558 def delete_project_location_reservation_group(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::Empty::Representation command.response_class = Google::Apis::BigqueryreservationV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#failover_reservation(name, failover_reservation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Fail over a reservation to the secondary location. The operation should be
done in the current secondary location, which will be promoted to the new
primary location for the reservation. Attempting to failover a reservation in
the current primary location will fail with the error code google.rpc.Code.
FAILED_PRECONDITION.
771 772 773 774 775 776 777 778 779 780 781 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 771 def failover_reservation(name, failover_reservation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:failoverReservation', ) command.request_representation = Google::Apis::BigqueryreservationV1::FailoverReservationRequest::Representation command.request_object = failover_reservation_request_object command.response_representation = Google::Apis::BigqueryreservationV1::Reservation::Representation command.response_class = Google::Apis::BigqueryreservationV1::Reservation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_bi_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::BiReservation
Retrieves a BI reservation.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 75 def get_project_location_bi_reservation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::BiReservation::Representation command.response_class = Google::Apis::BigqueryreservationV1::BiReservation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_capacity_commitment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Returns information about the capacity commitment.
333 334 335 336 337 338 339 340 341 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 333 def get_project_location_capacity_commitment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::CapacityCommitment::Representation command.response_class = Google::Apis::BigqueryreservationV1::CapacityCommitment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_reservation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Returns information about the reservation.
804 805 806 807 808 809 810 811 812 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 804 def get_project_location_reservation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::Reservation::Representation command.response_class = Google::Apis::BigqueryreservationV1::Reservation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_reservation_assignment_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Gets the access control policy for a resource. May return: * ANOT_FOUND
error if the resource doesn't exist or you don't have the permission to view
it. * An empty policy if the resource exists but doesn't have a set policy.
Supported resources are: - Reservations - ReservationAssignments To call this
method, you must have the following Google IAM permissions: -
bigqueryreservation.reservations.getIamPolicy to get policies on reservations.
1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1148 def get_project_location_reservation_assignment_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BigqueryreservationV1::Policy::Representation command.response_class = Google::Apis::BigqueryreservationV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_reservation_group(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ReservationGroup
Returns information about the reservation group.
589 590 591 592 593 594 595 596 597 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 589 def get_project_location_reservation_group(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BigqueryreservationV1::ReservationGroup::Representation command.response_class = Google::Apis::BigqueryreservationV1::ReservationGroup command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_reservation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Gets the access control policy for a resource. May return: * ANOT_FOUND
error if the resource doesn't exist or you don't have the permission to view
it. * An empty policy if the resource exists but doesn't have a set policy.
Supported resources are: - Reservations - ReservationAssignments To call this
method, you must have the following Google IAM permissions: -
bigqueryreservation.reservations.getIamPolicy to get policies on reservations.
852 853 854 855 856 857 858 859 860 861 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 852 def get_project_location_reservation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BigqueryreservationV1::Policy::Representation command.response_class = Google::Apis::BigqueryreservationV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_capacity_commitments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListCapacityCommitmentsResponse
Lists all the capacity commitments for the admin project.
368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 368 def list_project_location_capacity_commitments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/capacityCommitments', ) command.response_representation = Google::Apis::BigqueryreservationV1::ListCapacityCommitmentsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::ListCapacityCommitmentsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_reservation_assignments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListAssignmentsResponse
Lists assignments. Only explicitly created assignments will be returned.
Example: * Organization organizationA contains two projects, project1 and
project2. * Reservation res1 exists and was created previously. *
CreateAssignment was used previously to define the following associations
between entities and reservations: and In this example, ListAssignments
will just return the above two assignments for reservation res1, and no
expansion/merge will happen. The wildcard "-" can be used for reservations in
the request. In that case all assignments belongs to the specified project and
location will be listed. Note "-" cannot be used for projects nor
locations.
1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1193 def list_project_location_reservation_assignments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/assignments', ) command.response_representation = Google::Apis::BigqueryreservationV1::ListAssignmentsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::ListAssignmentsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_reservation_groups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListReservationGroupsResponse
Lists all the reservation groups for the project in the specified location.
624 625 626 627 628 629 630 631 632 633 634 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 624 def list_project_location_reservation_groups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/reservationGroups', ) command.response_representation = Google::Apis::BigqueryreservationV1::ListReservationGroupsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::ListReservationGroupsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ListReservationsResponse
Lists all the reservations for the project in the specified location.
888 889 890 891 892 893 894 895 896 897 898 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 888 def list_project_location_reservations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/reservations', ) command.response_representation = Google::Apis::BigqueryreservationV1::ListReservationsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::ListReservationsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#merge_capacity_commitments(parent, merge_capacity_commitments_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Merges capacity commitments of the same plan into a single commitment. The
resulting capacity commitment has the greater commitment_end_time out of the
to-be-merged capacity commitments. Attempting to merge capacity commitments of
different plan will fail with the error code google.rpc.Code.
FAILED_PRECONDITION.
406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 406 def merge_capacity_commitments(parent, merge_capacity_commitments_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/capacityCommitments:merge', ) command.request_representation = Google::Apis::BigqueryreservationV1::MergeCapacityCommitmentsRequest::Representation command.request_object = merge_capacity_commitments_request_object command.response_representation = Google::Apis::BigqueryreservationV1::CapacityCommitment::Representation command.response_class = Google::Apis::BigqueryreservationV1::CapacityCommitment command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#move_assignment(name, move_assignment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Assignment
Moves an assignment under a new reservation. This differs from removing an existing assignment and recreating a new one by providing a transactional change that ensures an assignee always has an associated reservation.
1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1229 def move_assignment(name, move_assignment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:move', ) command.request_representation = Google::Apis::BigqueryreservationV1::MoveAssignmentRequest::Representation command.request_object = move_assignment_request_object command.response_representation = Google::Apis::BigqueryreservationV1::Assignment::Representation command.response_class = Google::Apis::BigqueryreservationV1::Assignment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_capacity_commitment(name, capacity_commitment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Updates an existing capacity commitment. Only plan and renewal_plan fields
can be updated. Plan can only be changed to a plan of a longer commitment
period. Attempting to change to a plan with shorter commitment period will
fail with the error code google.rpc.Code.FAILED_PRECONDITION.
447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 447 def patch_project_location_capacity_commitment(name, capacity_commitment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigqueryreservationV1::CapacityCommitment::Representation command.request_object = capacity_commitment_object command.response_representation = Google::Apis::BigqueryreservationV1::CapacityCommitment::Representation command.response_class = Google::Apis::BigqueryreservationV1::CapacityCommitment command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_reservation(name, reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Reservation
Updates an existing reservation resource.
926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 926 def patch_project_location_reservation(name, reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigqueryreservationV1::Reservation::Representation command.request_object = reservation_object command.response_representation = Google::Apis::BigqueryreservationV1::Reservation::Representation command.response_class = Google::Apis::BigqueryreservationV1::Reservation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_reservation_assignment(name, assignment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Assignment
Updates an existing assignment. Only the priority field can be updated.
1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1267 def patch_project_location_reservation_assignment(name, assignment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigqueryreservationV1::Assignment::Representation command.request_object = assignment_object command.response_representation = Google::Apis::BigqueryreservationV1::Assignment::Representation command.response_class = Google::Apis::BigqueryreservationV1::Assignment command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_reservation_group(name, reservation_group_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::ReservationGroup
Updates an existing reservation group resource.
662 663 664 665 666 667 668 669 670 671 672 673 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 662 def patch_project_location_reservation_group(name, reservation_group_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigqueryreservationV1::ReservationGroup::Representation command.request_object = reservation_group_object command.response_representation = Google::Apis::BigqueryreservationV1::ReservationGroup::Representation command.response_class = Google::Apis::BigqueryreservationV1::ReservationGroup command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_all_assignments(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::SearchAllAssignmentsResponse
Looks up assignments for a specified resource for a particular region. If the
request is about a project: 1. Assignments created on the project will be
returned if they exist. 2. Otherwise assignments created on the closest
ancestor will be returned. 3. Assignments for different JobTypes will all be
returned. The same logic applies if the request is about a folder. If the
request is about an organization, then assignments created on the organization
will be returned (organization doesn't have ancestors). Comparing to
ListAssignments, there are some behavior differences: 1. permission on the
assignee will be verified in this API. 2. Hierarchy lookup (project->folder->
organization) happens in this API. 3. Parent here is projects/*/locations/*,
instead of projects/*/locations/*reservations/*.
123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 123 def search_project_location_all_assignments(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}:searchAllAssignments', ) command.response_representation = Google::Apis::BigqueryreservationV1::SearchAllAssignmentsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::SearchAllAssignmentsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['query'] = query unless query.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_assignments(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::SearchAssignmentsResponse
Deprecated: Looks up assignments for a specified resource for a particular
region. If the request is about a project: 1. Assignments created on the
project will be returned if they exist. 2. Otherwise assignments created on
the closest ancestor will be returned. 3. Assignments for different JobTypes
will all be returned. The same logic applies if the request is about a folder.
If the request is about an organization, then assignments created on the
organization will be returned (organization doesn't have ancestors). Comparing
to ListAssignments, there are some behavior differences: 1. permission on the
assignee will be verified in this API. 2. Hierarchy lookup (project->folder->
organization) happens in this API. 3. Parent here is projects/*/locations/*,
instead of projects/*/locations/*reservations/*. Note "-" cannot be used
for projects nor locations.
175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 175 def search_project_location_assignments(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}:searchAssignments', ) command.response_representation = Google::Apis::BigqueryreservationV1::SearchAssignmentsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::SearchAssignmentsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['query'] = query unless query.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_assignment_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Sets an access control policy for a resource. Replaces any existing policy.
Supported resources are: - Reservations To call this method, you must have the
following Google IAM permissions: - bigqueryreservation.reservations.
setIamPolicy to set policies on reservations.
1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1306 def set_assignment_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BigqueryreservationV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BigqueryreservationV1::Policy::Representation command.response_class = Google::Apis::BigqueryreservationV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_reservation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::Policy
Sets an access control policy for a resource. Replaces any existing policy.
Supported resources are: - Reservations To call this method, you must have the
following Google IAM permissions: - bigqueryreservation.reservations.
setIamPolicy to set policies on reservations.
965 966 967 968 969 970 971 972 973 974 975 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 965 def set_reservation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BigqueryreservationV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BigqueryreservationV1::Policy::Representation command.response_class = Google::Apis::BigqueryreservationV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#split_capacity_commitment(name, split_capacity_commitment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentResponse
Splits capacity commitment to two commitments of the same plan and
commitment_end_time. A common use case is to enable downgrading commitments.
For example, in order to downgrade from 10000 slots to 8000, you might split a
10000 capacity commitment into commitments of 2000 and 8000. Then, you delete
the first one after the commitment end time passes.
486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 486 def split_capacity_commitment(name, split_capacity_commitment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:split', ) command.request_representation = Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentRequest::Representation command.request_object = split_capacity_commitment_request_object command.response_representation = Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_assignment_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse
Gets your permissions on a resource. Returns an empty set of permissions if the resource doesn't exist. Supported resources are: - Reservations No Google IAM permissions are required to call this method.
1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1343 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BigqueryreservationV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_reservation_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse
Gets your permissions on a resource. Returns an empty set of permissions if the resource doesn't exist. Supported resources are: - Reservations No Google IAM permissions are required to call this method.
1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 1002 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BigqueryreservationV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BigqueryreservationV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_bi_reservation(name, bi_reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BigqueryreservationV1::BiReservation
Updates a BI reservation. Only fields specified in the field_mask are
updated. A singleton BI reservation always exists with default size 0. In
order to reserve BI capacity it needs to be updated to an amount greater than
- In order to release BI capacity reservation size must be set to 0.
216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/google/apis/bigqueryreservation_v1/service.rb', line 216 def update_project_location_bi_reservation(name, bi_reservation_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BigqueryreservationV1::BiReservation::Representation command.request_object = bi_reservation_object command.response_representation = Google::Apis::BigqueryreservationV1::BiReservation::Representation command.response_class = Google::Apis::BigqueryreservationV1::BiReservation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |