Class: Google::Apis::BigqueryreservationV1::FailoverReservationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb

Overview

The request for ReservationService.FailoverReservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FailoverReservationRequest

Returns a new instance of FailoverReservationRequest.



531
532
533
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failover_modeString

Optional. A parameter that determines how writes that are pending replication are handled after a failover is initiated. If not specified, HARD failover mode is used by default. Corresponds to the JSON property failoverMode

Returns:

  • (String)


529
530
531
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 529

def failover_mode
  @failover_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



536
537
538
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 536

def update!(**args)
  @failover_mode = args[:failover_mode] if args.key?(:failover_mode)
end