Class: Google::Apis::BigqueryreservationV1::ReservationGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb

Overview

A reservation group is a container for reservations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationGroup

Returns a new instance of ReservationGroup.



1073
1074
1075
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the reservation group, e.g., projects/*/ locations/*/reservationGroups/team1-prod. The reservation_group_id must only contain lower case alphanumeric characters or dashes. It must start with a letter and must not end with a dash. Its maximum length is 64 characters. Corresponds to the JSON property name

Returns:

  • (String)


1064
1065
1066
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1064

def name
  @name
end

#parent_groupString

Optional. The parent reservation group of the reservation group. Format: projects/*/locations/*/reservationGroups/team1-prod for non-root reservation groups, or projects/*/locations/* for root reservation groups. Corresponds to the JSON property parentGroup

Returns:

  • (String)


1071
1072
1073
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1071

def parent_group
  @parent_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1078
1079
1080
1081
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1078

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @parent_group = args[:parent_group] if args.key?(:parent_group)
end