Class: Google::Apis::BigqueryreservationV1::ListReservationGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryreservationV1::ListReservationGroupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb
Overview
The response for ReservationService.ListReservationGroups.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#reservation_groups ⇒ Array<Google::Apis::BigqueryreservationV1::ReservationGroup>
List of reservations visible to the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReservationGroupsResponse
constructor
A new instance of ListReservationGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReservationGroupsResponse
Returns a new instance of ListReservationGroupsResponse.
608 609 610 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
601 602 603 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 601 def next_page_token @next_page_token end |
#reservation_groups ⇒ Array<Google::Apis::BigqueryreservationV1::ReservationGroup>
List of reservations visible to the user.
Corresponds to the JSON property reservationGroups
606 607 608 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 606 def reservation_groups @reservation_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
613 614 615 616 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 613 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @reservation_groups = args[:reservation_groups] if args.key?(:reservation_groups) end |