Class: Google::Apis::BigqueryreservationV1::MergeCapacityCommitmentsRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryreservationV1::MergeCapacityCommitmentsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb
Overview
The request for ReservationService.MergeCapacityCommitments.
Instance Attribute Summary collapse
-
#capacity_commitment_id ⇒ String
Optional.
-
#capacity_commitment_ids ⇒ Array<String>
Ids of capacity commitments to merge.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MergeCapacityCommitmentsRequest
constructor
A new instance of MergeCapacityCommitmentsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MergeCapacityCommitmentsRequest
Returns a new instance of MergeCapacityCommitmentsRequest.
665 666 667 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_commitment_id ⇒ String
Optional. The optional resulting capacity commitment ID. Capacity commitment
name will be generated automatically if this field is empty. This field must
only contain lower case alphanumeric characters or dashes. The first and last
character cannot be a dash. Max length is 64 characters.
Corresponds to the JSON property capacityCommitmentId
655 656 657 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 655 def capacity_commitment_id @capacity_commitment_id end |
#capacity_commitment_ids ⇒ Array<String>
Ids of capacity commitments to merge. These capacity commitments must exist
under admin project and location specified in the parent. ID is the last
portion of capacity commitment name e.g., 'abc' for projects/myproject/
locations/US/capacityCommitments/abc
Corresponds to the JSON property capacityCommitmentIds
663 664 665 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 663 def capacity_commitment_ids @capacity_commitment_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
670 671 672 673 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 670 def update!(**args) @capacity_commitment_id = args[:capacity_commitment_id] if args.key?(:capacity_commitment_id) @capacity_commitment_ids = args[:capacity_commitment_ids] if args.key?(:capacity_commitment_ids) end |