Class: Google::Apis::BigqueryreservationV1::MoveAssignmentRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryreservationV1::MoveAssignmentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb
Overview
The request for ReservationService.MoveAssignment. Note: "bigquery. reservationAssignments.create" permission is required on the destination_id. ** Note**: "bigquery.reservationAssignments.create" and "bigquery. reservationAssignments.delete" permission are required on the related assignee.
Instance Attribute Summary collapse
-
#assignment_id ⇒ String
The optional assignment ID.
-
#destination_id ⇒ String
The new reservation ID, e.g.:
projects/myotherproject/locations/US/ reservations/team2-prodCorresponds to the JSON propertydestinationId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MoveAssignmentRequest
constructor
A new instance of MoveAssignmentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MoveAssignmentRequest
Returns a new instance of MoveAssignmentRequest.
696 697 698 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 696 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignment_id ⇒ String
The optional assignment ID. A new assignment name is generated if this field
is empty. This field can contain only lowercase alphanumeric characters or
dashes. Max length is 64 characters.
Corresponds to the JSON property assignmentId
688 689 690 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 688 def assignment_id @assignment_id end |
#destination_id ⇒ String
The new reservation ID, e.g.: projects/myotherproject/locations/US/
reservations/team2-prod
Corresponds to the JSON property destinationId
694 695 696 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 694 def destination_id @destination_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
701 702 703 704 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 701 def update!(**args) @assignment_id = args[:assignment_id] if args.key?(:assignment_id) @destination_id = args[:destination_id] if args.key?(:destination_id) end |