Class: Google::Apis::BigqueryreservationV1::ReplicationStatus
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryreservationV1::ReplicationStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb
Overview
Disaster Recovery(DR) replication status of the reservation.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::BigqueryreservationV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#last_error_time ⇒ String
Output only.
-
#last_replication_time ⇒ String
Output only.
-
#soft_failover_start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplicationStatus
constructor
A new instance of ReplicationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplicationStatus
Returns a new instance of ReplicationStatus.
837 838 839 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::BigqueryreservationV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
814 815 816 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 814 def error @error end |
#last_error_time ⇒ String
Output only. The time at which the last error was encountered while trying to
replicate changes from the primary to the secondary. This field is only
available if the replication has not succeeded since.
Corresponds to the JSON property lastErrorTime
821 822 823 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 821 def last_error_time @last_error_time end |
#last_replication_time ⇒ String
Output only. A timestamp corresponding to the last change on the primary that
was successfully replicated to the secondary.
Corresponds to the JSON property lastReplicationTime
827 828 829 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 827 def last_replication_time @last_replication_time end |
#soft_failover_start_time ⇒ String
Output only. The time at which a soft failover for the reservation and its
associated datasets was initiated. After this field is set, all subsequent
changes to the reservation will be rejected unless a hard failover overrides
this operation. This field will be cleared once the failover is complete.
Corresponds to the JSON property softFailoverStartTime
835 836 837 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 835 def soft_failover_start_time @soft_failover_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
842 843 844 845 846 847 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 842 def update!(**args) @error = args[:error] if args.key?(:error) @last_error_time = args[:last_error_time] if args.key?(:last_error_time) @last_replication_time = args[:last_replication_time] if args.key?(:last_replication_time) @soft_failover_start_time = args[:soft_failover_start_time] if args.key?(:soft_failover_start_time) end |