Class: Google::Apis::BigqueryreservationV1::ReservationGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb

Overview

A reservation group is a container for reservations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationGroup

Returns a new instance of ReservationGroup.



1056
1057
1058
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the reservation group, e.g., projects/*/ locations/*/reservationGroups/team1-prod. The reservation_group_id must only contain lower case alphanumeric characters or dashes. It must start with a letter and must not end with a dash. Its maximum length is 64 characters. Corresponds to the JSON property name

Returns:

  • (String)


1054
1055
1056
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1054

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1061
1062
1063
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1061

def update!(**args)
  @name = args[:name] if args.key?(:name)
end