Class: Google::Apis::BigqueryreservationV1::SchedulingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryreservationV1::SchedulingPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb
Overview
The scheduling policy controls how a reservation's resources are distributed.
Instance Attribute Summary collapse
-
#concurrency ⇒ Fixnum
Optional.
-
#max_slots ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchedulingPolicy
constructor
A new instance of SchedulingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchedulingPolicy
Returns a new instance of SchedulingPolicy.
1092 1093 1094 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#concurrency ⇒ Fixnum
Optional. If present and > 0, the reservation will attempt to limit the
concurrency of jobs running for any particular project within it to the given
value. This feature is not yet generally available.
Corresponds to the JSON property concurrency
1083 1084 1085 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1083 def concurrency @concurrency end |
#max_slots ⇒ Fixnum
Optional. If present and > 0, the reservation will attempt to limit the slot
consumption of queries running for any particular project within it to the
given value. This feature is not yet generally available.
Corresponds to the JSON property maxSlots
1090 1091 1092 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1090 def max_slots @max_slots end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1097 1098 1099 1100 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1097 def update!(**args) @concurrency = args[:concurrency] if args.key?(:concurrency) @max_slots = args[:max_slots] if args.key?(:max_slots) end |