Class: Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb
Overview
The response for ReservationService.SplitCapacityCommitment.
Instance Attribute Summary collapse
-
#first ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Capacity commitment is a way to purchase compute capacity for BigQuery jobs ( in the form of slots) with some committed period of usage.
-
#second ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Capacity commitment is a way to purchase compute capacity for BigQuery jobs ( in the form of slots) with some committed period of usage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SplitCapacityCommitmentResponse
constructor
A new instance of SplitCapacityCommitmentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SplitCapacityCommitmentResponse
Returns a new instance of SplitCapacityCommitmentResponse.
1251 1252 1253 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#first ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Capacity commitment is a way to purchase compute capacity for BigQuery jobs (
in the form of slots) with some committed period of usage. Annual commitments
renew by default. Commitments can be removed after their commitment end time
passes. In order to remove annual commitment, its plan needs to be changed to
monthly or flex first. A capacity commitment resource exists as a child
resource of the admin project.
Corresponds to the JSON property first
1239 1240 1241 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1239 def first @first end |
#second ⇒ Google::Apis::BigqueryreservationV1::CapacityCommitment
Capacity commitment is a way to purchase compute capacity for BigQuery jobs (
in the form of slots) with some committed period of usage. Annual commitments
renew by default. Commitments can be removed after their commitment end time
passes. In order to remove annual commitment, its plan needs to be changed to
monthly or flex first. A capacity commitment resource exists as a child
resource of the admin project.
Corresponds to the JSON property second
1249 1250 1251 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1249 def second @second end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1256 1257 1258 1259 |
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1256 def update!(**args) @first = args[:first] if args.key?(:first) @second = args[:second] if args.key?(:second) end |