Class: Google::Apis::BigqueryreservationV1::SplitCapacityCommitmentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigqueryreservation_v1/classes.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb,
lib/google/apis/bigqueryreservation_v1/representations.rb

Overview

The response for ReservationService.SplitCapacityCommitment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitCapacityCommitmentResponse

Returns a new instance of SplitCapacityCommitmentResponse.



1243
1244
1245
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firstGoogle::Apis::BigqueryreservationV1::CapacityCommitment

Capacity commitment is a way to purchase compute capacity for BigQuery jobs ( in the form of slots) with some committed period of usage. Annual commitments renew by default. Commitments can be removed after their commitment end time passes. In order to remove annual commitment, its plan needs to be changed to monthly or flex first. A capacity commitment resource exists as a child resource of the admin project. Corresponds to the JSON property first



1231
1232
1233
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1231

def first
  @first
end

#secondGoogle::Apis::BigqueryreservationV1::CapacityCommitment

Capacity commitment is a way to purchase compute capacity for BigQuery jobs ( in the form of slots) with some committed period of usage. Annual commitments renew by default. Commitments can be removed after their commitment end time passes. In order to remove annual commitment, its plan needs to be changed to monthly or flex first. A capacity commitment resource exists as a child resource of the admin project. Corresponds to the JSON property second



1241
1242
1243
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1241

def second
  @second
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1248
1249
1250
1251
# File 'lib/google/apis/bigqueryreservation_v1/classes.rb', line 1248

def update!(**args)
  @first = args[:first] if args.key?(:first)
  @second = args[:second] if args.key?(:second)
end